==> wls-plugin-1.2.1-sources.jar: com/xebialabs/deployit/plugin/wls/step/destroy-jms-module.py <==
#
# Copyright (c) 2010 XebiaLabs B.V. All rights reserved.
#
# Your use of Xebialabs Software and Documentation is subject to the Personal
# License Agreement.
# http://www.xebialabs.com/deployit-personal-edition-license-agreement
# You are granted a personal license (i) to use the Software for your own
# personal purposes which may be used in a production environment and/or (ii)
# to use the Documentation to develop your own plugins to the Software.
# ‚ÄúDocumentation‚Äù means the how to's and instructions (instruction videos)
# provided with the Software and/or available on the XebiaLabs website or other
# websites as well as the provided API documentation, tutorial and access to
# the source code of the Xebialabs plugins. You agree not to (i) lease, rent
# or sublicense the Software or Documentation to any third party, or otherwise
# use it except as permitted in this agreement; (ii) reverse engineer,
# decompile, disassemble, or otherwise attempt to determine source code or
# protocols from the Software, and/or to  (iii) copy the Software or
# Documentation (which includes the source code of the XebiaLabs plugins). You
# shall not create or attempt to create any derivative works from the Software
# except and only to the extent permitted by law. You will preserve XebiaLabs'
# copyright and legal notices on the Software and Documentation. XebiaLabs
# retains all rights not expressly granted to You in the Personal License
# Agreement.
#

import sys
import os
import time as ptime

ignore = sys.argv.pop(0)
user = sys.argv.pop(0)
password = sys.argv.pop(0)
url = sys.argv.pop(0)

modulename = sys.argv.pop(0)

servernames = []
jmsservernames = []
filestores = []
dirs = []
module2serversnames = []
while len(sys.argv) >= 5:
    servernames.append(sys.argv.pop(0))
    jmsservernames.append(sys.argv.pop(0))
    filestores.append(sys.argv.pop(0))
    dirs.append(sys.argv.pop(0))
    module2serversnames.append(sys.argv.pop(0))
    

def destroyMessageService(moduleName, jmsservers, filestores):
  log('Destroying JMSSystemResource '+ moduleName)
  cd("/")
  cmo.destroyJMSSystemResource(getMBean('/SystemResources/' + moduleName))
  for jmsserver in jmsservers:
      cmo.destroyJMSServer(getMBean('/Deployments/' + jmsserver))
  for filestore in filestores:
      cmo.destroyFileStore(getMBean('/FileStores/' + filestore))

#==============================#
# Logging method               #
#==============================#
def log(msg, level="info"):
    print ptime.strftime("%H:%M:%S", ptime.localtime()) + " <" + level + "> " + msg
    return

connect(user, password, url)
edit()
startEdit()
destroyMessageService(modulename, jmsservernames, filestores)
save()
disconnect('true')
exit('y')

==> wls-plugin-1.2.2-sources.jar: com/xebialabs/deployit/plugin/wls/step/destroy-jms-module.py <==
#
# Copyright (c) 2010 XebiaLabs B.V. All rights reserved.
#
# Your use of XebiaLabs Software and Documentation is subject to the Personal
# License Agreement.
#
# http://www.xebialabs.com/deployit-personal-edition-license-agreement
#
# You are granted a personal license (i) to use the Software for your own
# personal purposes which may be used in a production environment and/or (ii)
# to use the Documentation to develop your own plugins to the Software.
# "Documentation" means the how to's and instructions (instruction videos)
# provided with the Software and/or available on the XebiaLabs website or other
# websites as well as the provided API documentation, tutorial and access to
# the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
# or sublicense the Software or Documentation to any third party, or otherwise
# use it except as permitted in this agreement; (ii) reverse engineer,
# decompile, disassemble, or otherwise attempt to determine source code or
# protocols from the Software, and/or to  (iii) copy the Software or
# Documentation (which includes the source code of the XebiaLabs plugins). You
# shall not create or attempt to create any derivative works from the Software
# except and only to the extent permitted by law. You will preserve XebiaLabs'
# copyright and legal notices on the Software and Documentation. XebiaLabs
# retains all rights not expressly granted to You in the Personal License
# Agreement.
#

import sys
import os
import time as ptime

ignore = sys.argv.pop(0)
user = sys.argv.pop(0)
password = sys.argv.pop(0)
url = sys.argv.pop(0)
jmsModuleName = sys.argv.pop(0)

print "Connecting to WebLogic"
connect(user, password, url)
edit()
startEdit()

print "Destroying JMS Module " + jmsModuleName
cmo.destroyJMSSystemResource(getMBean('/SystemResources/' + jmsModuleName))

print "Saving configuration"
save()
disconnect('true')
exit('y')
